@@ -27,7 +27,8 @@ is_windows <- function() {
 
 # This is needed to avoid checking the class of fs_path objects in the
 # tests.
-compare.fs_path <- function(x, y) {
+# @export
+compare.fs_path <- function(x, y, ...) {
   if (identical(class(y), "character")) {
     class(x) <- NULL
   }
@@ -36,7 +37,8 @@ compare.fs_path <- function(x, y) {
   NextMethod("compare")
 }
 
-compare.fs_perms <- function(x, y) {
+# @export
+compare.fs_perms <- function(x, y, ...) {
   if (!inherits(y, "fs_perms")) {
     y <- as.character(as_fs_perms(y))
     x <- as.character(x)
@@ -112,7 +114,7 @@ assert <- function(msg, ..., class = "invalid_argument") {
   tests <- unlist(list(...))
 
   if (!all(tests)) {
-    stop(fs_error(msg, ..., class = class))
+    stop(fs_error(msg, class = class))
   }
 }
 
